@@ -1,8 +1,8 @@
 /*
  * Compiz configuration system library
  *
- * Copyright (C) 2007  Dennis Kasprzyk <onestone@beryl-project.org>
- * Copyright (C) 2007  Danny Baumann <maniac@beryl-project.org>
+ * Copyright (C) 2007  Dennis Kasprzyk <onestone@compiz.org>
+ * Copyright (C) 2007  Danny Baumann <dannybaumann@web.de>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -182,17 +182,19 @@ struct _CCSPlugin
 
 typedef enum _CCSSettingType
 {
+    /* This needs to be in the same order as CompOptionType for consistency */
     TypeBool,
     TypeInt,
     TypeFloat,
     TypeString,
     TypeColor,
-    TypeMatch,
-    TypeList,
+    TypeAction,
     TypeKey,
     TypeButton,
     TypeEdge,
     TypeBell,
+    TypeMatch,
+    TypeList,
     TypeNum
 } CCSSettingType;
 
@@ -713,6 +715,8 @@ void ccsIniClose (IniDictionary *dictionary);
 void ccsIniSave (IniDictionary *dictionary,
 		 const char    *fileName);
 
+Bool ccsCreateDirFor (const char *fileName);
+
 Bool ccsIniGetString (IniDictionary *dictionary,
 		      const char    *section,
 		      const char    *entry,
