@@ -1,7 +1,7 @@
 /*
  * Compiz configuration system library
  *
- * Copyright (C) 2007  Dennis Kasprzyk <onestone@opencompositing.org>
+ * Copyright (C) 2007  Dennis Kasprzyk <onestone@compiz.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -23,6 +23,8 @@
 #include <google/protobuf/io/zero_copy_stream_impl.h>
 #endif
 
+#include <libxml/xpath.h>
+
 extern "C"
 {
 #ifdef HAVE_CONFIG_H
@@ -36,9 +38,6 @@ extern "C"
 #include <sys/stat.h>
 #include <errno.h>
 
-#include <libxslt/transform.h>
-#include <libxslt/xsltutils.h>
-
 #include <locale.h>
 
 #include <compiz-core.h>
@@ -48,6 +47,19 @@ extern "C"
 
 extern int xmlLoadExtDtdDefaultValue;
 
+static const char *
+getLocale ()
+{
+    char *lang = getenv ("LC_ALL");
+
+    if (!lang || !strlen (lang))
+	lang = getenv ("LC_MESSAGES");
+
+    if (!lang || !strlen (lang))
+	lang = getenv ("LANG");
+
+    return lang ? lang : "";
+}
 
 #ifdef USE_PROTOBUF
 
@@ -74,20 +86,6 @@ PluginMetadata persistentPluginPB; // Made global so that it gets reused,
 
 std::string metadataCacheDir = "";
 
-static char *
-getLocale ()
-{
-    char *lang = getenv ("LANG");
-
-    if (!lang || !strlen (lang))
-	lang = getenv ("LC_ALL");
-
-    if (!lang || !strlen (lang))
-	lang = getenv ("LC_MESSAGES");
-
-    return lang ? lang : (char *)"";
-}
-
 std::string curLocale = std::string (getLocale ());
 std::string shortLocale = curLocale.find ('.') == std::string::npos ?
     curLocale : curLocale.substr (0, curLocale.find ('.'));
@@ -1136,18 +1134,10 @@ stringFromNodeDef (xmlNode * node, const char *path, const char *def)
 static char *
 stringFromNodeDefTrans (xmlNode * node, const char *path, const char *def)
 {
-    char *lang;
+    const char *lang = getLocale ();
     char newPath[1024];
     char *rv = NULL;
 
-    lang = getenv ("LANG");
-
-    if (!lang || !strlen (lang))
-	lang = getenv ("LC_ALL");
-
-    if (!lang || !strlen (lang))
-	lang = getenv ("LC_MESSAGES");
-
     if (!lang || !strlen (lang))
 	return stringFromNodeDef (node, path, def);
 
@@ -2880,6 +2870,12 @@ loadPluginsFromXMLFiles (CCSContext * context, char *path)
 
     if (!path)
 	return;
+#if defined(HAVE_SCANDIR_POSIX)
+ // POSIX (2008) defines the comparison function like this:
+ #define scandir(a,b,c,d) scandir((a), (b), (c), (int(*)(const dirent **, const dirent **))(d));
+#else
+ #define scandir(a,b,c,d) scandir((a), (b), (c), (int(*)(const void*,const void*))(d));
+#endif
 
     nFile = scandir (path, &nameList, pluginXMLFilter, NULL);
 
