@@ -1,8 +1,8 @@
 /*
  * Compiz configuration system library
  *
- * Copyright (C) 2007  Dennis Kasprzyk <onestone@opencompositing.org>
- * Copyright (C) 2007  Danny Baumann <maniac@opencompositing.org>
+ * Copyright (C) 2007  Dennis Kasprzyk <onestone@compiz.org>
+ * Copyright (C) 2007  Danny Baumann <dannybaumann@web.de>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -626,6 +626,7 @@ openBackend (char *backend)
 Bool
 ccsSetBackend (CCSContext * context, char *name)
 {
+    Bool	 fallbackMode = FALSE;
     CONTEXT_PRIV (context);
 
     if (cPrivate->backend)
@@ -646,6 +647,7 @@ ccsSetBackend (CCSContext * context, char *name)
     void *dlhand = openBackend (name);
     if (!dlhand)
     {
+	fallbackMode = TRUE;
 	name = "ini";
 	dlhand = openBackend (name);
     }
@@ -680,7 +682,8 @@ ccsSetBackend (CCSContext * context, char *name)
 	cPrivate->backend->vTable->backendInit (context);
 
     ccsDisableFileWatch (cPrivate->configWatchId);
-    ccsWriteConfig (OptionBackend, name);
+    if (!fallbackMode)
+	ccsWriteConfig (OptionBackend, name);
     ccsEnableFileWatch (cPrivate->configWatchId);
 
     return TRUE;
